import { SimpleJournalEditor } from "@/components/SimpleJournalEditor";
import { AdUnit } from "@/components/AdUnit";
import { Timer } from "@/components/Timer";
import { Accordion, AccordionContent, AccordionItem, AccordionTrigger } from "@/components/ui/accordion";
import { SocialSharing } from "@/components/SocialSharing";
import { FeedbackForm } from "@/components/FeedbackForm";

export default function Home() {

  return (
    <div className="min-h-screen flex flex-col bg-[#121212] text-[#F5F5F5]">
      <header className="pt-6 pb-2 px-4 sm:px-6 md:px-8 lg:px-12 xl:px-16" role="banner">
        <div className="max-w-7xl mx-auto flex items-center justify-between">
          <div className="flex items-center justify-between w-full">
            <div className="flex items-center">
              <div className="font-serif text-2xl sm:text-3xl text-[#FF5722]">Burnal</div>
              <p className="ml-2 text-sm text-[#BDBDBD]" aria-label="Tagline">Write. Vent. Burn.</p>
            </div>
            <nav className="hidden md:flex space-x-4" role="navigation" aria-label="Main navigation">
              <a href="/" className="text-gray-300 hover:text-orange-400 transition-colors text-sm">Home</a>
              <a href="/about" className="text-gray-300 hover:text-orange-400 transition-colors text-sm">About</a>
              <a href="/privacy" className="text-gray-300 hover:text-orange-400 transition-colors text-sm">Privacy</a>
            </nav>
          </div>
          
          {/* Timer temporarily removed to fix React hooks error */}
        </div>
      </header>
      <main className="flex-grow flex flex-col items-center justify-start pt-8 px-4 sm:px-6 md:px-8 lg:px-12 xl:px-16" role="main">
        <div className="w-full max-w-7xl mx-auto">
          <div className="grid grid-cols-1 xl:grid-cols-12 gap-4 lg:gap-6 xl:gap-8">
            {/* Left Sidebar Ad */}
            <aside className="hidden xl:block xl:col-span-2" role="complementary" aria-label="Advertisement">
              <div className="sticky top-4">
                <AdUnit 
                  adSlot="9356652203"
                  adFormat="vertical"
                  className="mb-4"
                />
              </div>
            </aside>
            
            {/* Main Content */}
            <section className="xl:col-span-8" role="main">
              <div className="mb-6 text-center">
                <h1 className="text-2xl sm:text-3xl md:text-4xl lg:text-5xl xl:text-6xl font-bold text-white mb-3">Digital Therapeutic Journaling</h1>
                <p className="text-sm sm:text-base md:text-lg lg:text-xl text-[#BDBDBD] mb-4 max-w-4xl mx-auto">Transform stress into strength through private writing.</p>
                

                
                
                <p className="text-xs text-[#BDBDBD]">All entries are automatically deleted after 2 minutes of inactivity or when you leave the page. <a href="/privacy" className="text-orange-400 hover:text-orange-300 underline">Read our privacy policy</a> for complete details on data protection.</p>
              </div>
              
              {/* Top Banner Ad (Mobile) */}
              <div className="lg:hidden mb-6">
                <AdUnit 
                  adSlot="7361044256"
                  adFormat="horizontal"
                  className="text-center"
                />
              </div>
              
              <div className="mt-4">
                <SimpleJournalEditor />
              </div>
              
              {/* Start Your Digital Detox Journey section - moved below editor */}
              <div className="max-w-4xl mx-auto mt-8 mb-8">
                <div className="bg-gray-700/30 rounded-lg p-6 border border-gray-600/30">
                  <h2 className="text-xl font-semibold text-orange-300 mb-4 text-center">Start Your Digital Detox Journey</h2>
                  <div className="grid grid-cols-1 md:grid-cols-3 gap-6 text-sm text-[#E0E0E0]">
                    <div className="text-center">
                      <h3 className="font-medium text-orange-200 mb-2">Express Freely</h3>
                      <p className="text-xs">Write your deepest thoughts without judgment or fear of permanent storage. <a href="/privacy" className="text-orange-400 hover:text-orange-300 underline">Learn about our privacy protections</a>.</p>
                    </div>
                    <div className="text-center">
                      <h3 className="font-medium text-orange-200 mb-2">Release Ritual</h3>
                      <p className="text-xs">Watch your words transform into beautiful flames, symbolizing emotional release. <a href="/about" className="text-orange-400 hover:text-orange-300 underline">Discover the science behind therapeutic writing</a>.</p>
                    </div>
                    <div className="text-center">
                      <h3 className="font-medium text-orange-200 mb-2">Move Forward</h3>
                      <p className="text-xs">Experience closure and peace as your thoughts disappear, leaving you lighter. <a href="/" className="text-orange-400 hover:text-orange-300 underline">Begin your healing journey</a>.</p>
                    </div>
                  </div>
                </div>
              </div>
              
              {/* Why Choose Burnal section moved after editor */}
              <div className="mt-8 mb-8">
                <div className="max-w-4xl mx-auto text-left">
                  <div className="bg-gray-800/30 rounded-lg p-6 border border-gray-700/30">
                    <h2 className="text-2xl font-semibold text-orange-300 mb-4">Why Choose Burnal for Mental Wellness?</h2>
                    <div className="text-[#E0E0E0] space-y-4">
                      <p>Burnal is a revolutionary digital therapeutic journaling platform designed to provide emotional release through expressive writing. Our privacy-first approach ensures your most personal thoughts remain completely confidential while offering the mental health benefits of therapeutic writing documented by <a href="https://www.va.gov/WHOLEHEALTHLIBRARY/tools/therapeutic-journaling.asp" target="_blank" rel="noopener noreferrer" className="text-orange-400 hover:text-orange-300 underline">25+ years of research summarized by the U.S. Department of Veterans Affairs</a>.</p>
                      
                      <p>A <a href="https://www.frontiersin.org/journals/psychology/articles/10.3389/fpsyg.2022.825626/full" target="_blank" rel="noopener noreferrer" className="text-orange-400 hover:text-orange-300 underline">comprehensive 40-year review of 1,429 studies</a> confirms that expressive writing yields positive results across cognitive, emotional, social, and biological domains - including stronger immune function, improved mood, and reduced anxiety and depression symptoms. With Burnal's unique burning animation feature, you experience a powerful ritual of release - watching your worries transform into beautiful flames and disappear forever. Explore our <a href="/about" className="text-orange-400 hover:text-orange-300 underline">science-backed approach</a> to digital therapy.</p>
                      
                      <div className="grid grid-cols-1 md:grid-cols-2 gap-6 mt-6">
                        <div>
                          <h3 className="text-lg font-medium text-orange-200 mb-2">Complete Privacy Protection</h3>
                          <p className="text-sm">No user accounts required. No data stored on servers. Automatic deletion after 2 minutes ensures your thoughts remain truly private. Learn more about our <a href="/privacy" className="text-orange-400 hover:text-orange-300 underline">privacy policy</a> or <a href="/about" className="text-orange-400 hover:text-orange-300 underline">how our security works</a>.</p>
                        </div>
                        <div>
                          <h3 className="text-lg font-medium text-orange-200 mb-2">Scientifically-Backed Benefits</h3>
                          <p className="text-sm">Studies published in <a href="https://www.cambridge.org/core/journals/advances-in-psychiatric-treatment/article/emotional-and-physical-health-benefits-of-expressive-writing/ED2976A61F5DE56B46F07A1CE9EA9F9F" target="_blank" rel="noopener noreferrer" className="text-orange-400 hover:text-orange-300 underline">Advances in Psychiatric Treatment</a> show that writing about traumatic or stressful events for just 15-20 minutes over a few days produces significant improvements in both physical and psychological health. A recent <a href="https://pmc.ncbi.nlm.nih.gov/articles/PMC8935176/" target="_blank" rel="noopener noreferrer" className="text-orange-400 hover:text-orange-300 underline">systematic review and meta-analysis</a> confirms journaling as a low-cost, low-risk therapeutic tool with positive effects on anxiety, depression, and PTSD symptoms. <a href="/about" className="text-orange-400 hover:text-orange-300 underline">Discover more research findings</a>.</p>
                        </div>
                      </div>
                      
                      <div className="mt-6 text-center">
                        <p className="text-sm text-[#BDBDBD]">
                          Ready to start your healing journey? <a href="/" className="text-orange-400 hover:text-orange-300 underline mx-1">Begin writing above</a> or explore our 
                          <a href="/about" className="text-orange-400 hover:text-orange-300 underline mx-1">therapeutic features</a>, 
                          <a href="/privacy" className="text-orange-400 hover:text-orange-300 underline mx-1">privacy protections</a>, and 
                          <a href="/about" className="text-orange-400 hover:text-orange-300 underline mx-1">scientific research</a>.
                        </p>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
              
              {/* Content Rectangle Ad - strategically placed between sections */}
              <div className="mt-8 mb-6 flex justify-center">
                <AdUnit 
                  adSlot="6047962586"
                  adFormat="rectangle"
                  className="max-w-md mx-auto"
                />
              </div>

              {/* Additional substantial content */}
              <div className="mt-8 space-y-6">
                <div className="bg-gray-800/20 rounded-lg p-6 border border-gray-700/30">
                  <h2 className="text-lg font-semibold text-orange-300 mb-4">The Science Behind Digital Catharsis</h2>
                  <div className="text-sm text-[#E0E0E0] space-y-3">
                    <p>
                      Expressive writing therapy has been validated through decades of research showing significant mental health benefits. Writing about traumatic or stressful events for 15-20 minutes over a few days produces improvements in both physical and psychological health, including enhanced immune function, reduced cortisol levels, and decreased symptoms of anxiety and depression.
                    </p>
                    <p>
                      Our burning animation adds a scientifically-backed ritualistic element that amplifies the therapeutic effect. A <a href="https://www.nagoya-u.ac.jp/researchinfo/result-en/2024/04/20240410-01.html" target="_blank" rel="noopener noreferrer" className="text-orange-400 hover:text-orange-300 underline">2024 study in Scientific Reports</a> found that participants who wrote about anger-provoking experiences and then physically destroyed their writing had their anger "eliminated almost entirely," while those who kept their writings remained measurably angry. This symbolic destruction creates powerful psychological closure, helping users truly "let go" of processed emotions.
                    </p>
                    <p>
                      The combination of digital privacy, automatic deletion, and visual transformation creates a safe space for authentic emotional expression. Research by <a href="https://artsandsciences.osu.edu/news/tossing-negative-thoughts-really-works" target="_blank" rel="noopener noreferrer" className="text-orange-400 hover:text-orange-300 underline">Dr. Richard Petty at Ohio State University</a> demonstrates that physically destroying written negative thoughts reduces their psychological impact, while keeping them enhances their influence. Burnal's digital "burning" harnesses this same principle - the act of symbolic destruction helps the mind truly release processed emotions.
                    </p>
                    <div className="grid grid-cols-1 md:grid-cols-3 gap-4 mt-4">
                      <div className="text-center">
                        <div className="text-orange-400 font-bold text-lg">2 min</div>
                        <div className="text-xs">Auto-deletion timer</div>
                        <div className="text-xs mt-1"><a href="/privacy" className="text-orange-400 hover:text-orange-300 underline">Privacy details</a></div>
                      </div>
                      <div className="text-center">
                        <div className="text-orange-400 font-bold text-lg">4 styles</div>
                        <div className="text-xs">Burning animations</div>
                        <div className="text-xs mt-1"><a href="/about" className="text-orange-400 hover:text-orange-300 underline">Animation guide</a></div>
                      </div>
                      <div className="text-center">
                        <div className="text-orange-400 font-bold text-lg">100%</div>
                        <div className="text-xs">Privacy guaranteed</div>
                        <div className="text-xs mt-1"><a href="/privacy" className="text-orange-400 hover:text-orange-300 underline">Read policy</a></div>
                      </div>
                    </div>
                  </div>
                </div>
                
                {/* Bottom Content Ad */}
                <div className="text-center">
                  <AdUnit 
                    adSlot="6047962586"
                    adFormat="rectangle"
                    className="text-center"
                  />
                </div>
                
                {/* How to Use Burnal Section */}
                <div className="bg-gray-800/20 rounded-lg p-6 border border-gray-700/30 mb-6">
                  <h2 className="text-lg font-semibold text-orange-300 mb-4">How to Use Burnal for Maximum Therapeutic Benefit</h2>
                  <div className="text-sm text-[#E0E0E0] space-y-4">
                    <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
                      <div>
                        <h3 className="text-base font-medium text-orange-200 mb-2">Step 1: Create Your Safe Space</h3>
                        <p>Find a quiet, private moment where you won't be interrupted. Burnal works best when you can write authentically without external pressures or distractions. Learn more about <a href="/about" className="text-orange-400 hover:text-orange-300 underline">creating optimal writing environments</a>.</p>
                      </div>
                      <div>
                        <h3 className="text-base font-medium text-orange-200 mb-2">Step 2: Write Without Censoring</h3>
                        <p>Express your thoughts freely, knowing they will disappear completely. Write about stress, anxiety, frustrations, or any emotions you need to process. Review our <a href="/privacy" className="text-orange-400 hover:text-orange-300 underline">complete privacy guarantee</a>.</p>
                      </div>
                      <div>
                        <h3 className="text-base font-medium text-orange-200 mb-2">Step 3: Choose Your Release Ritual</h3>
                        <p>Select from our four burning animation styles to match your emotional state. Each style offers a different symbolic representation of letting go. Learn more <a href="/about" className="text-orange-400 hover:text-orange-300 underline">about animation styles</a>.</p>
                      </div>
                      <div>
                        <h3 className="text-base font-medium text-orange-200 mb-2">Step 4: Experience the Release</h3>
                        <p>Watch your words transform into beautiful flames and disappear forever. This symbolic destruction provides what researchers call "backward magical contagion" - by destroying the physical representation of your emotions, your mind follows suit and releases them. Studies show this ritualistic approach creates complete emotional catharsis, leaving participants feeling significantly lighter and more at peace.</p>
                      </div>
                    </div>
                    <div className="mt-6 p-4 bg-gray-700/30 rounded-lg">
                      <h4 className="font-medium text-orange-200 mb-2">Best Practices for Therapeutic Writing & Release</h4>
                      <ul className="text-xs space-y-1 list-disc list-inside">
                        <li>Write continuously for at least 5-10 minutes without stopping - this sustained expression allows for deeper emotional processing. <a href="/about" className="text-orange-400 hover:text-orange-300 underline">Learn optimal writing techniques</a>.</li>
                        <li>Focus on your deepest emotions and thoughts, not just surface-level events - therapeutic benefits come from honest emotional disclosure. <a href="/privacy" className="text-orange-400 hover:text-orange-300 underline">Your privacy is completely protected</a>.</li>
                        <li>Don't worry about grammar, spelling, or writing quality - <a href="https://therapistaid.com/therapy-guide/letter-writing-in-therapy" target="_blank" rel="noopener noreferrer" className="text-orange-400 hover:text-orange-300 underline">therapists recommend</a> free expression without self-censoring. <a href="/" className="text-orange-400 hover:text-orange-300 underline">Start writing freely now</a>.</li>
                        <li>Embrace the burning ritual - research shows the physical act of destruction is crucial for emotional release, not just imagining it. <a href="/about" className="text-orange-400 hover:text-orange-300 underline">Discover the science behind symbolic destruction</a>.</li>
                        <li>Use Burnal regularly for consistent benefits - <a href="https://pmc.ncbi.nlm.nih.gov/articles/PMC6305886/" target="_blank" rel="noopener noreferrer" className="text-orange-400 hover:text-orange-300 underline">clinical trials</a> demonstrate ongoing journaling creates lasting improvements in psychological well-being. <a href="/" className="text-orange-400 hover:text-orange-300 underline">Begin your regular practice</a>.</li>
                        <li>Take deep breaths before and after your writing session to enhance the meditative aspects of the practice. <a href="/about" className="text-orange-400 hover:text-orange-300 underline">Explore mindfulness techniques</a>.</li>
                      </ul>
                    </div>
                  </div>
                </div>

                {/* Strategic ad before FAQ section */}
                <div className="my-8 flex justify-center">
                  <AdUnit 
                    adSlot="7361044256"
                    adFormat="horizontal"
                    className="max-w-2xl mx-auto"
                  />
                </div>

                {/* FAQ Section with Accordion */}
                <div className="bg-gray-800/20 rounded-lg p-6 border border-gray-700/30">
                  <h2 className="text-lg font-semibold text-orange-300 mb-4">Frequently Asked Questions</h2>
                  <Accordion type="single" collapsible className="w-full">
                    <AccordionItem value="getting-started" className="border-gray-600">
                      <AccordionTrigger className="text-orange-200 hover:text-orange-300">
                        How do I get started?
                      </AccordionTrigger>
                      <AccordionContent className="text-[#E0E0E0] text-sm">
                        <div className="space-y-2">
                          <p>Simply start typing in the text area above. No registration or setup required.</p>
                          <p>When you're ready to release your thoughts, click "Burn It All" and choose your preferred animation style. The key is in the complete destruction - research shows that merely imagining disposal has no effect, but the actual symbolic act creates measurable emotional relief. Learn more about <a href="/about" className="text-orange-400 hover:text-orange-300 underline">our therapeutic approach</a> based on this proven psychological mechanism.</p>
                        </div>
                      </AccordionContent>
                    </AccordionItem>

                    <AccordionItem value="timer" className="border-gray-600">
                      <AccordionTrigger className="text-orange-200 hover:text-orange-300">
                        What happens after 2 minutes?
                      </AccordionTrigger>
                      <AccordionContent className="text-[#E0E0E0] text-sm">
                        <div className="space-y-2">
                          <p>Your content automatically deletes after 2 minutes of inactivity to ensure complete privacy.</p>
                          <p>You can also manually burn your content anytime using the burn button. Researchers found that the timing of destruction matters - those who destroyed their writings immediately experienced complete emotional relief, while delayed destruction was less effective. Read more about our <a href="/privacy" className="text-orange-400 hover:text-orange-300 underline">privacy protection</a> and how <a href="https://pmc.ncbi.nlm.nih.gov/articles/PMC10415981/" target="_blank" rel="noopener noreferrer" className="text-orange-400 hover:text-orange-300 underline">meta-analytic research</a> shows expressive writing improves emotional regulation.</p>
                        </div>
                      </AccordionContent>
                    </AccordionItem>

                    <AccordionItem value="devices" className="border-gray-600">
                      <AccordionTrigger className="text-orange-200 hover:text-orange-300">
                        Can I use Burnal on mobile?
                      </AccordionTrigger>
                      <AccordionContent className="text-[#E0E0E0] text-sm">
                        <div className="space-y-2">
                          <p>Yes! Burnal works perfectly on all devices - desktop, tablet, and mobile.</p>
                          <p>The interface adapts to your screen size for comfortable writing anywhere. Research confirms that digital journaling offers the same therapeutic benefits as traditional methods. <a href="https://traumaresearchuk.org/healing-through-unsent-letters/" target="_blank" rel="noopener noreferrer" className="text-orange-400 hover:text-orange-300 underline">Trauma recovery organizations</a> recommend writing combined with symbolic destruction as particularly effective for processing difficult emotions and achieving closure.</p>
                        </div>
                      </AccordionContent>
                    </AccordionItem>

                    {/* Mid-FAQ Ad placement for better engagement */}
                    <div className="my-6 flex justify-center">
                      <AdUnit 
                        adSlot="6047962586"
                        adFormat="horizontal"
                        className="max-w-lg mx-auto"
                      />
                    </div>

                    <AccordionItem value="animation-styles" className="border-gray-600">
                      <AccordionTrigger className="text-orange-200 hover:text-orange-300">
                        Animation Styles Guide
                      </AccordionTrigger>
                      <AccordionContent className="text-[#E0E0E0] text-sm">
                        <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
                          <div>
                            <h4 className="font-medium text-orange-200 mb-2">Classic Fire</h4>
                            <p className="text-xs mb-3">Traditional flame effect inspired by therapeutic burning rituals found across cultures. Text transforms into glowing embers that rise and fade away naturally, mimicking the ancient practice of releasing burdens through ceremonial fire. <a href="/about" className="text-orange-400 hover:text-orange-300 underline">Learn more about cultural burning practices</a>.</p>
                            
                            <h4 className="font-medium text-orange-200 mb-2">Explosive</h4>
                            <p className="text-xs">Dramatic burst effect for intense emotional release. Research shows that the more dramatic the symbolic destruction, the greater the sense of cathartic relief experienced by participants. <a href="/about" className="text-orange-400 hover:text-orange-300 underline">Discover the research behind symbolic destruction</a>.</p>
                          </div>
                          <div>
                            <h4 className="font-medium text-orange-200 mb-2">Floating Embers</h4>
                            <p className="text-xs mb-3">Gentle, meditative destruction where text slowly dissolves into floating particles. This style provides the therapeutic benefits of symbolic release while maintaining a peaceful, contemplative atmosphere for processing difficult emotions. <a href="/privacy" className="text-orange-400 hover:text-orange-300 underline">Your privacy is guaranteed</a> throughout the process.</p>
                            
                            <h4 className="font-medium text-orange-200 mb-2">Spiral Flame</h4>
                            <p className="text-xs">Hypnotic spiral pattern that creates a mesmerizing transformation ritual. The circular motion symbolizes the cyclical nature of emotional healing and helps users feel a complete sense of closure and renewal. <a href="/" className="text-orange-400 hover:text-orange-300 underline">Start your healing journey now</a>.</p>
                          </div>
                        </div>
                      </AccordionContent>
                    </AccordionItem>
                  </Accordion>
                </div>
              </div>
            </section>
            
            {/* Right Sidebar Ad */}
            <aside className="hidden xl:block xl:col-span-2" role="complementary" aria-label="Advertisement">
              <div className="sticky top-4">
                <AdUnit 
                  adSlot="9283935368"
                  adFormat="vertical"
                  className="mb-4"
                />
              </div>
            </aside>
          </div>
        </div>
      </main>
      <footer className="pt-8 pb-16 px-4 text-center" role="contentinfo">
        {/* Footer Banner Ad */}
        <div className="max-w-4xl mx-auto mb-8">
          <AdUnit 
            adSlot="9165080511"
            adFormat="horizontal"
            className="text-center"
          />
        </div>
        
        <div className="max-w-4xl mx-auto grid grid-cols-1 md:grid-cols-3 gap-8 mb-6">
          <div className="col-span-1">
            <SocialSharing />
          </div>
          
          <div className="col-span-1 md:col-span-2 flex flex-col justify-center">
            <p className="text-[#BDBDBD] text-sm">Your words are never stored on our servers. Everything stays in your browser until it burns away. Learn more about <a href="/about" className="text-orange-400 hover:text-orange-300 underline">how Burnal works</a>, review our complete <a href="/privacy" className="text-orange-400 hover:text-orange-300 underline">privacy commitment</a>, or <a href="/" className="text-orange-400 hover:text-orange-300 underline">return to journaling</a>.</p>
            <nav className="mt-2 text-[#BDBDBD] text-xs space-y-1" aria-label="Footer navigation">
              <div className="space-x-4">
                <a 
                  href="/" 
                  className="text-orange-400 hover:text-orange-300 transition-colors underline"
                >
                  Home
                </a>
                <a 
                  href="/about" 
                  className="text-orange-400 hover:text-orange-300 transition-colors underline"
                >
                  About
                </a>
                <a 
                  href="/privacy" 
                  className="text-orange-400 hover:text-orange-300 transition-colors underline"
                >
                  Privacy Policy
                </a>
              </div>
              <p>© {new Date().getFullYear()} Burnal - <a href="/about" className="text-orange-400 hover:text-orange-300 underline">Therapeutic Digital Catharsis</a></p>
            </nav>
          </div>
        </div>
        
        {/* Feedback form fixed button */}
        <FeedbackForm />
      </footer>
    </div>
  );
}
